@@ -2,9 +2,10 @@ inference <- function(object, ...) {
     UseMethod("inference")
 }
 
+
 #' @export
-inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
-                             survey.options, ...) {
+inference.inzdot <- function(object, des, bs, opts, class, width,
+                             vn, hypothesis, survey.options, ...) {
     toplot <- object$toplot
     inf <- object$inference.info
 
@@ -22,15 +23,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
     ci.width <- attr(inf, "ci.width")
     mat <- inf$mean$conf[, c("mean", "lower", "upper"), drop = FALSE]
 
-    mat <- matrix(
-        apply(
-            mat, 2,
-            function(col) {
-                format(col, digits = 4)
-            }
-        ),
-        nrow = nrow(mat)
-    )
+    mat <- format(mat, digits = opts$signif)
 
     ## Remove NA's and replace with an empty space
     mat[grep("NA", mat)] <- ""
@@ -86,15 +79,16 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
         ## BOOTSTRAP MEDIAN
         mat <- inf$median$conf[, c("mean", "lower", "upper"), drop = FALSE]
 
-        mat <- matrix(
-            apply(
-                mat, 2,
-                function(col) {
-                    format(col, digits = 4)
-                }
-            ),
-            nrow = nrow(mat)
-        )
+        mat <- format(mat, digits = opts$signif)
+        # mat <- matrix(
+        #     apply(
+        #         mat, 2,
+        #         function(col) {
+        #             format(col, digits = opts$signif)
+        #         }
+        #     ),
+        #     nrow = nrow(mat)
+        # )
 
         ## Remove NA's and replace with an empty space
         mat[grep("NA", mat)] <- ""
@@ -143,15 +137,16 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
         ## BOOTSTRAP INTERQUARTILE RANGE
         mat <- inf$iqr$conf[, c("mean", "lower", "upper"), drop = FALSE]
 
-        mat <- matrix(
-            apply(
-                mat, 2,
-                function(col) {
-                    format(col, digits = 4)
-                }
-            ),
-            nrow = nrow(mat)
-        )
+        mat <- format(mat, digits = opts$signif)
+        # mat <- matrix(
+        #     apply(
+        #         mat, 2,
+        #         function(col) {
+        #             format(col, digits = opts$signif)
+        #         }
+        #     ),
+        #     nrow = nrow(mat)
+        # )
 
         ## Remove NA's and replace with an empty space
         mat[grep("NA", mat)] <- ""
@@ -221,7 +216,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                 }
 
                 if (!inherits(test.out, "try-error")) {
-                    pval <- format.pval(test.out$p.value)
+                    pval <- format_pval(test.out$p.value, opts)
                     out <- c(
                         out,
                         "",
@@ -268,7 +263,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                         svar <- sapply(toplot, function(d) var(d$x))
                         sn <- sapply(toplot, function(d) length(d$x))
                         var.pooled <- sum((sn - 1) * svar) / sum(sn - 1)
-                        pval <- format.pval(ftest$p.value)
+                        pval <- format_pval(ftest$p.value, opts)
                         out <- c(
                             out,
                             "",
@@ -349,7 +344,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                 fpval <- pf(fstat[1], fstat[2], fstat[3], lower.tail = FALSE)
                 Fname <- "One-way Analysis of Variance (ANOVA F-test)"
             }
-            fpval <- format.pval(fpval, digits = 5)
+            fpval <- format_pval(fpval, opts, digits = 5)
 
             Ftest <- c(
                 Fname,
@@ -396,7 +391,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                     ci <- confint(ttest, level = ci.width)
                     mat <- rbind(
                         c("Estimate", "Lower", "Upper"),
-                        format(-c(ttest$estimate[[1]], ci[[2]], ci[[1]]), digits = 4)
+                        format(-c(ttest$estimate[[1]], ci[[2]], ci[[1]]), digits = opts$signif)
                     )
                     colnames(mat) <- NULL
                 }
@@ -413,7 +408,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                             ttest$conf.int[1],
                             ttest$conf.int[2]
                         ),
-                        digits = 4
+                        digits = opts$signif
                     )
                 )
                 colnames(mat) <- NULL
@@ -486,12 +481,12 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                     apply(
                         mc, 2,
                         function(col) {
-                            format(col, digits = 4, justify = "right")
+                            format(col, digits = opts$signif, justify = "right")
                         }
                     ),
                     nrow = nrow(mc)
                 )
-                mat[, 4] <- format.pval(as.numeric(mat[, 4]))
+                mat[, 4] <- format_pval(as.numeric(mat[, 4]), opts)
                 mat[grep("NA", mat)] <- ""
 
                 rnames <- lapply(strsplit(rownames(mc), " - "), trimws)
@@ -563,7 +558,7 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
                 mu = hypothesis$value
             )
         }
-        pval <- format.pval(test.out$p.value)
+        pval <- format_pval(test.out$p.value, opts)
         out <- c(
             out,
             "",
@@ -601,21 +596,22 @@ inference.inzdot <- function(object, des, bs, class, width, vn, hypothesis,
     out
 }
 
-formatTriMat <- function(mat, names) {
+formatTriMat <- function(mat, names, digits = 3) {
     ## Formats a (lower) triangular matrix nicely for display:
 
     mat[!lower.tri(mat)] <- NA
     mat <- mat[-1, , drop = FALSE]
 
-    mat <- matrix(
-        apply(
-            mat, 2,
-            function(col) {
-                format(col, digits = 4)
-            }
-        ),
-        nrow = nrow(mat)
-    )
+    mat <- format(mat, digits = digits)
+    # mat <- matrix(
+    #     apply(
+    #         mat, 2,
+    #         function(col) {
+    #             format(col, digits = digits)
+    #         }
+    #     ),
+    #     nrow = nrow(mat)
+    # )
 
     mat[grep("NA", mat)] <- ""
     mat[grep("NaN", mat)] <- ""
@@ -650,15 +646,16 @@ formatMat <- function(mat, digits = 4) {
         mat <- matrix(mat, ncol = 1)
     }
 
-    mat <- matrix(
-        apply(
-            mat, 2,
-            function(col) {
-                format(col, digits = digits)
-            }
-        ),
-        nrow = nrow(mat)
-    )
+    mat <- format(mat, digits = digits)
+    # mat <- matrix(
+    #     apply(
+    #         mat, 2,
+    #         function(col) {
+    #             format(col, digits = digits)
+    #         }
+    #     ),
+    #     nrow = nrow(mat)
+    # )
     mat[grep("NA", mat)] <- ""
     mat[grep("NaN", mat)] <- ""
 
@@ -680,18 +677,20 @@ formatMat <- function(mat, digits = 4) {
     mat
 }
 
+
 #' @export
-inference.inzhist <- function(object, des, bs, class, width, vn, hypothesis,
+inference.inzhist <- function(object, des, bs, opts, class, width, vn, hypothesis,
                               survey.options, ...) {
     inference.inzdot(
-        object, des, bs, class, width, vn, hypothesis,
+        object, des, bs, opts, class, width, vn, hypothesis,
         survey.options, ...
     )
 }
 
 
+
 #' @export
-inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
+inference.inzbar <- function(object, des, bs, opts, nb, vn, hypothesis,
                              survey.options, epi.out = FALSE, ...) {
     phat <- object$phat
     inf <- object$inference.info
@@ -741,7 +740,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
                                 "   Z-score = %s, p-value %s%s",
                                 format(signif(prtest$statistic, 5)),
                                 ifelse(prtest$p.value < 2.2e-16, "", "= "),
-                                format.pval(prtest$p.value, digits = 5)
+                                format_pval(prtest$p.value, opts, digits = 5)
                             ),
                             "",
                             sprintf(
@@ -818,7 +817,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
                                     )
                                 ),
                                 ifelse(prtest$p.value < 2.2e-16, "", "= "),
-                                format.pval(prtest$p.value, digits = 5)
+                                format_pval(prtest$p.value, opts, digits = 5)
                             ),
                             "",
                             sprintf(
@@ -893,7 +892,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
                             "\n   Simulated p-value%s %s%s",
                             chi2out,
                             ifelse(chi2sim$p.value < 2.2e-16, "", "= "),
-                            format.pval(chi2sim$p.value, digits = 5)
+                            format_pval(chi2sim$p.value, opts, digits = 5)
                         )
                     }
 
@@ -915,7 +914,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
                             ", ",
                             "p-value ",
                             ifelse(chi2$p.value < 2.2e-16, "", "= "),
-                            format.pval(chi2$p.value, digits = 5),
+                            format_pval(chi2$p.value, opts, digits = 5),
                             simpval
                         ),
                         "",
@@ -935,15 +934,16 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
         mat <- inf$conf$estimate
         dn <- dimnames(object$tab)
 
-        mat <- matrix(
-            apply(
-                mat, 2,
-                function(col) {
-                    format(col, digits = 3)
-                }
-            ),
-            nrow = nrow(mat)
-        )
+        mat <- format(mat, digits = opts$signif)
+        # mat <- matrix(
+        #     apply(
+        #         mat, 2,
+        #         function(col) {
+        #             format(col, digits = opts$signif)
+        #         }
+        #     ),
+        #     nrow = nrow(mat)
+        # )
 
         ## Remove NA's and replace with an empty space
         mat[grep("NA", mat)] <- ""
@@ -980,15 +980,16 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
         cis <- rbind(cis$lower, cis$upper)
         cis <- cis[rep(1:nrow(phat), each = 2) + c(0, nrow(phat)), ]
 
-        cis <- matrix(
-            apply(
-                cis, 2,
-                function(col) {
-                    format(col, digits = 3)
-                }
-            ),
-            nrow = nrow(cis)
-        )
+        cis <- format(cis, digits = opts$signif)
+        # cis <- matrix(
+        #     apply(
+        #         cis, 2,
+        #         function(col) {
+        #             format(col, digits = opts$signif)
+        #         }
+        #     ),
+        #     nrow = nrow(cis)
+        # )
         cis[grep("NA", cis)] <- ""
         cis[grep("NaN", cis)] <- ""
 
@@ -1110,7 +1111,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
                 apply(
                     diffs[3:5], 2,
                     function(col) {
-                        format(col, digits = 4L, justify = "right")
+                        format(col, digits = opts$signif, justify = "right")
                     }
                 ),
                 nrow = nrow(diffs)
@@ -1242,15 +1243,16 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
     } else { ## one-way table
         mat <- t(rbind(inf$conf$estimate, inf$conf$lower, inf$conf$upper))
 
-        mat <- matrix(
-            apply(
-                mat, 2,
-                function(col) {
-                    format(col, digits = 3)
-                }
-            ),
-            nrow = nrow(mat)
-        )
+        mat <- format(mat, digits = opts$signif)
+        # mat <- matrix(
+        #     apply(
+        #         mat, 2,
+        #         function(col) {
+        #             format(col, digits = opts$signif)
+        #         }
+        #     ),
+        #     nrow = nrow(mat)
+        # )
 
         ## Remove NA's and replace with an empty space
         mat[grep("NA", mat)] <- ""
@@ -1349,7 +1351,7 @@ inference.inzbar <- function(object, des, bs, nb, vn, hypothesis,
             apply(
                 diffs[3:5], 2,
                 function(col) {
-                    format(col, digits = 4L, justify = "right")
+                    format(col, digits = opts$signif, justify = "right")
                 }
             ),
             nrow = nrow(diffs)
@@ -1541,7 +1543,7 @@ pDiffCI <- function(p1, p2, n1, n2, z = 1.96) {
 }
 
 #' @export
-inference.inzscatter <- function(object, des, bs, nb, vn, survey.options, ...) {
+inference.inzscatter <- function(object, des, bs, opts, nb, vn, survey.options, ...) {
     d <- data.frame(
         x = object$x,
         y = object$y,
@@ -1633,7 +1635,7 @@ inference.inzscatter <- function(object, des, bs, nb, vn, survey.options, ...) {
                     sprintf("%.5g", cc[, 1]),
                     sprintf("%.5g", ci[, 1]),
                     sprintf("%.5g", ci[, 2]),
-                    format.pval(cc[, 4], digits = 2)
+                    format_pval(cc[, 4], opts, digits = opts$signif)
                 )
             }
 
@@ -1694,11 +1696,11 @@ inference.inzscatter <- function(object, des, bs, nb, vn, survey.options, ...) {
 }
 
 #' @export
-inference.inzgrid <- function(object, bs, nboot, vn, survey.options, ...) {
-    inference.inzscatter(object, bs, nboot, vn, survey.options, ...)
+inference.inzgrid <- function(object, bs, opts, nboot, vn, survey.options, ...) {
+    inference.inzscatter(object, bs, opts, nboot, vn, survey.options, ...)
 }
 
 #' @export
-inference.inzhex <- function(object, bs, nboot, vn, survey.options, ...) {
-    inference.inzscatter(object, bs, nboot, vn, survey.options, ...)
+inference.inzhex <- function(object, bs, opts, nboot, vn, survey.options, ...) {
+    inference.inzscatter(object, bs, opts, nboot, vn, survey.options, ...)
 }
